import { BasicColumn } from '/@/components/Table';
import { FormSchema } from '/@/components/Table';
import { optionsListApi, optionsListApi2, optionsListApi3 } from '/@/api/tigerapi/wms/inventory';
import { h, unref } from 'vue';
import { Tag, Tooltip } from 'ant-design-vue';
import { useI18n } from '/@/hooks/web/useI18n';
import { useLocale } from '/@/locales/useLocale';
const { getLocale } = useLocale();
const { t } = useI18n('WMS.Count');
//盘点主界面 
export const columns: BasicColumn[] = [
  {
    title: t('单据编码'),
    dataIndex: 'COUNT_NO',
    resizable: true,
    sorter: true,
    width: 200,
  },
  {
    title: t('镜像时间'),
    dataIndex: 'MIRROR_DATE',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: t('创建者'),
    dataIndex: 'CREATE_USER',
    resizable: true,
    sorter: true,
    width: 180,
  },
  // {
  //   title: t('仓库'),
  //   dataIndex: 'WH_CODE',
  //   resizable:true,
  // },
  {
    title: t('状态'),
    dataIndex: 'STATUS',
    resizable: true,
    sorter: true,
    width: 180,
    customRender: ({ record }) => {
      const status = record.STATUS;
      var text = '';
      var color = '';
      switch (status) {
        case 0:
          text = '新创建';
          color = 'green';
          break;
        case 1:
          text = '盘点中';
          color = 'blue';
          break;
        case 2:
          text = '暂停中';
          color = '#C2C247';
          break;
        case 3:
          text = '已关闭';
          color = '#C2C247';
          break;
        case 4:
          text = '作废';
          color = '#C2C247';
          break;
        default:
          break;
      }
      return h(Tooltip, { title: t('xxxxxx') }, () => h(Tag, { color: color }, () => text));
    },
  },
  {
    title: t('盘点类型'),
    dataIndex: 'COUNT_TYPE',
    resizable: true,
    sorter: true,
    width: 180,
    customRender: ({ record }) => {
      const status = record.COUNT_TYPE;
      var text = '';
      var color = '';
      switch (status) {
        case 0:
          text = '年盘';
          color = 'green';
          break;
        case 1:
          text = '季盘';
          color = 'blue';
          break;
        case 2:
          text = '月盘';
          color = '#C2C247';
          break;
        case 3:
          text = '周盘';
          color = '#C2C247';
          break;
        case 4:
          text = '日盘';
          color = '#C2C247';
          break;
        default:
          break;
      }
      return h(Tooltip, { title: t('xxxxxx') }, () => h(Tag, { color: color }, () => text));
    },
  },
  {
    title: t('盘点开始时间'),
    dataIndex: 'BEGIN_DATE',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: t('盘点结束时间'),
    dataIndex: 'END_DATE',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: t('备注'),
    dataIndex: 'REMARK',
    resizable: true,
    sorter: true,
    width: 180,
  },
];
//盘点管理中盘点信息
export const newFormSchema: FormSchema[] = [
  {
    field: 'COUNT_NO',
    label: t('盘点单号'),
    colProps: { span: 8 },
    component: 'Input',
    dynamicDisabled: true
  },
  {
    field: 'COUNT_TYPE',
    label: t('盘点类型'),
    component: 'ApiSelect',
    colProps: { span: 8 },
    componentProps: {
      api: optionsListApi2,
      resultField: 'Data',
      labelField: unref(getLocale) == 'zh_CN' ? 'Desc' : 'Name',
      valueField: 'Value',
      // onChange: (e, v) => {
      //   alert(e)
      //   console.log('ApiSelect====>:', e, v);
      // },
    },
  },
  {
    field: 'MIRROR_DATE',
    label: t('镜像时间'),
    colProps: { span: 8 },
    component: 'Input',
    dynamicDisabled: true
  },
  {
    field: 'COUNT_MODE',
    label: t('盘点模式'),
    component: 'ApiSelect',
    colProps: { span: 8 },
    componentProps: {
      api: optionsListApi3,
      resultField: 'Data',
      labelField: unref(getLocale) == 'zh_CN' ? 'Desc' : 'Name',
      valueField: 'Value',
      // onChange: (e, v) => {
      //   alert(e)
      //   console.log('ApiSelect====>:', e, v);
      // },
    },
  },
  {
    field: 'ITEM_CODE_LIST',
    label: t('物料编码列表'),
    colProps: { span: 8 },
    component: 'Input',
  },
  {
    field: '0',
    component: 'Input',
    label: t(' '),
    colSlot: 'add',
    colProps: {
      span: 8,
    },
  },
  {
    field: 'ID',
    label: t('ID'),
    colProps: { span: 8 },
    component: 'Input',
    dynamicDisabled: true,
    show: false
  },
  {
    field: 'WH_IDS',
    label: t('仓库'),
    colProps: { span: 8 },
    component: 'Input',
    dynamicDisabled: true,
    show: false
  },
  {
    field: 'REGION_IDS',
    label: t('储区'),
    colProps: { span: 8 },
    component: 'Input',
    dynamicDisabled: true,
    show: false
  },
  {
    field: 'SHELF_IDS',
    label: t('货架'),
    colProps: { span: 8 },
    component: 'Input',
    dynamicDisabled: true,
    show: false
  },
  {
    field: 'LOCATION_IDS',
    label: t('货架'),
    colProps: { span: 8 },
    component: 'Input',
    dynamicDisabled: true,
    show: false
  },
  {
    field: 'ORG_CODE',
    label: t('ORG_CODE'),
    colProps: { span: 8 },
    component: 'Input',
    dynamicDisabled: true,
    show: false
  },
  {
    field: 'STATUS',
    label: t('STATUS'),
    colProps: { span: 8 },
    component: 'Input',
    dynamicDisabled: true,
    show: false
  },
  {
    field: 'CREATE_USER',
    label: t('CREATE_USER'),
    colProps: { span: 8 },
    component: 'Input',
    dynamicDisabled: true,
    show: false
  },
  {
    field: 'CREATE_TIME',
    label: t('CREATE_TIME'),
    colProps: { span: 8 },
    component: 'Input',
    dynamicDisabled: true,
    show: false
  },
  {
    field: 'AUTH_ORE',
    label: t('AUTH_ORE'),
    colProps: { span: 8 },
    component: 'Input',
    dynamicDisabled: true,
    show: false
  },
  {
    field: 'AUTH_PROD',
    label: t('AUTH_PROD'),
    colProps: { span: 8 },
    component: 'Input',
    dynamicDisabled: true,
    show: false
  },
  {
    field: 'AUTH_WH',
    label: t('AUTH_WH'),
    colProps: { span: 8 },
    component: 'Input',
    dynamicDisabled: true,
    show: false
  },
  {
    field: 'CREATE_USER',
    label: t('CREATE_USER'),
    colProps: { span: 8 },
    component: 'Input',
    dynamicDisabled: true,
    show: false
  }, {
    field: 'UPDATE_USER',
    label: t('UPDATE_USER'),
    colProps: { span: 8 },
    component: 'Input',
    dynamicDisabled: true,
    show: false
  },
  {
    field: 'BEGIN_DATE',
    label: t('BEGIN_DATE'),
    colProps: { span: 8 },
    component: 'Input',
    dynamicDisabled: true,
    show: false
  },
  {
    field: 'END_DATE',
    label: t('END_DATE'),
    colProps: { span: 8 },
    component: 'Input',
    dynamicDisabled: true,
    show: false
  },
];
//盘点管理中的盘点明细
export const dtlColumns: BasicColumn[] = [
  {
    title: t('物料编码'),
    dataIndex: 'ITEM_CODE',
    resizable: true,
    sorter: true,
    width: 200,
  },
  {
    title: t('物料名称'),
    dataIndex: 'ITEM_NAME',
    resizable: true,
    sorter: true,
    width: 180,
  },
  // {
  //   title: t('物料描述'),
  //   dataIndex: 'ITEM_DESC',
  //   resizable:true,
  // },
  {
    title: t('数量'),
    dataIndex: 'QTY',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: t('条码数量'),
    dataIndex: 'SN_COUNT',
    resizable: true,
    sorter: true,
    width: 180,
  },
];
//查询条件
export const searchFormSchema: FormSchema[] = [
  {
    field: 'COUNT_NO',
    label: t('单据编码'),
    colProps: { span: 8 },
    component: 'Input',
  },
  {
    field: 'STATUS',
    label: t('状态'),
    component: 'ApiSelect',
    colProps: { span: 8 },
    componentProps: {
      api: optionsListApi,
      resultField: 'Data',
      labelField: unref(getLocale) == 'zh_CN' ? 'Desc' : 'Name',
      valueField: 'Value',
      // onChange: (e, v) => {
      //   alert(e)
      //   console.log('ApiSelect====>:', e, v);
      // },
    },
  },
  {
    field: 'COUNT_TYPE',
    label: t('盘点类型'),
    component: 'ApiSelect',
    colProps: { span: 8 },
    componentProps: {
      api: optionsListApi2,
      resultField: 'Data',
      labelField: unref(getLocale) == 'zh_CN' ? 'Desc' : 'Name',
      valueField: 'Value',
      // onChange: (e, v) => {
      //   alert(e)
      //   console.log('ApiSelect====>:', e, v);
      // },
    },
  },
  {
    field: 'MIRROR_DATE',
    label: t('镜像时间'),
    colProps: { span: 8 },
    component: 'RangePicker',
  },
  {
    field: 'COUNT_MODE',
    label: t('盘点模式'),
    component: 'ApiSelect',
    colProps: { span: 8 },
    componentProps: {
      api: optionsListApi3,
      resultField: 'Data',
      labelField: unref(getLocale) == 'zh_CN' ? 'Desc' : 'Name',
      valueField: 'Value',
      // onChange: (e, v) => {
      //   alert(e)
      //   console.log('ApiSelect====>:', e, v);
      // },
    },
  },
];
//物料列表
export const ItemColumns: BasicColumn[] = [
  {
    title: t('物料编码'),
    dataIndex: 'ITEM_CODE',
    resizable: true,
    sorter: true,
    width: 200,
  },
  {
    title: t('物料名称'),
    dataIndex: 'ITEM_NAME',
    resizable: true,
    sorter: true,
    width: 180,
  },
  // {
  //   title: t('物料描述'),
  //   dataIndex: 'ITEM_DESC',
  //   resizable:true,
  // },
  // {
  //   title: t('盘点状态',
  //   dataIndex: 'STATUS',
  //   resizable:true,
  // },
  // {
  //   title: t('盘点结果',
  //   dataIndex: 'RESULT',
  //   resizable:true,
  // },
  // {
  //   title: t('WMS数量',
  //   dataIndex: 'QTY',
  //   resizable:true,
  // },
  // {
  //   title: t('ACT_QTY',
  //   dataIndex: 'COUNT_TYPE',
  //   resizable:true,
  // }
];
//物品明细(OK)
export const MdtlColumns: BasicColumn[] = [
  {
    title: t('物料编码'),
    dataIndex: 'ITEM_CODE',
    resizable: true,
    sorter: true,
    width: 200,
  },
  {
    title: t('操作时间'),
    dataIndex: 'UPDATE_TIME',
    resizable: true,
    sorter: true,
    width: 300,
  },
  {
    title: t('条码'),
    dataIndex: 'SN',
    resizable: true,
    sorter: true,
    width: 350,
  },
  {
    title: t('储位代码'),
    dataIndex: 'LOCATION_CODE',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: t('物料名称'),
    dataIndex: 'ITEM_NAME',
    resizable: true,
    sorter: true,
    width: 350,
  },
  {
    title: t('状态'),
    dataIndex: 'STATUS',
    resizable: true,
    sorter: true,
    width: 180,
    customRender: ({ record }) => {
      const status = record.STATUS;
      var text = '';
      var color = '';
      switch (status) {
        case 0:
          text = '待盘点';
          color = 'green';
          break;
        case 1:
          text = '已盘点';
          color = 'blue';
          break;
        default:
          break;
      }
      return h(Tooltip, { title: t('xxxxxx') }, () => h(Tag, { color: color }, () => text));
    },
  },
  {
    title: t('结果'),
    dataIndex: 'RESULT',
    resizable: true,
    sorter: true,
    width: 180,
    customRender: ({ record }) => {
      const status = record.RESULT;
      var text = '';
      var color = '';
      switch (status) {
        case 0:
          text = '无结果';
          color = 'green';
          break;
        case 1:
          text = '平帐';
          color = 'blue';
          break;
        case 2:
          text = '盘盈';
          color = '#C2C247';
          break;
        case 3:
          text = '盘亏';
          color = '#C2C247';
          break;
        default:
          break;
      }
      return h(Tooltip, { title: t('xxxxxx') }, () => h(Tag, { color: color }, () => text));
    },
  },
  {
    title: t('库存数量'),
    dataIndex: 'QTY',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: t('盘点数量'),
    dataIndex: 'ACT_QTY',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: t('未盘点数量'),
    dataIndex: 'NOT_QTY',
    resizable: true,
    sorter: true,
    width: 180,
  },
]
//储位明细
export const LdtlColumns: BasicColumn[] = [
  {
    title: t('物料编码'),
    dataIndex: 'ITEM_CODE',
    resizable: true,
    sorter: true,
    width: 200,
  },
  {
    title: t('状态'),
    dataIndex: 'STATUS',
    resizable: true,
    sorter: true,
    width: 180,
    customRender: ({ record }) => {
      const status = record.STATUS;
      var text = '';
      var color = '';
      switch (status) {
        case 0:
          text = '待盘点';
          color = 'green';
          break;
        case 1:
          text = '已盘点';
          color = 'blue';
          break;
        default:
          break;
      }
      return h(Tooltip, { title: t('xxxxxx') }, () => h(Tag, { color: color }, () => text));
    },
  },
  {
    title: t('结果'),
    dataIndex: 'RESULT',
    resizable: true,
    sorter: true,
    width: 180,
    customRender: ({ record }) => {
      const status = record.RESULT;
      var text = '';
      var color = '';
      switch (status) {
        case 0:
          text = '未核实';
          color = 'green';
          break;
        case 1:
          text = '已核实';
          color = 'blue';
          break;
        case 2:
          text = '新找到';
          color = '#C2C247';
          break;
        default:
          break;
      }
      return h(Tooltip, { title: t('xxxxxx') }, () => h(Tag, { color: color }, () => text));
    },
  },
  {
    title: t('储位'),
    dataIndex: 'LOCATION_CODE',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: t('库存数量'),
    dataIndex: 'QTY',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: t('盘点数量'),
    dataIndex: 'ACT_QTY',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: t('未盘点数量'),
    dataIndex: 'NOT_QTY',
    resizable: true,
    sorter: true,
    width: 180,
  },
]
//汇总明细
export const SumColumns: BasicColumn[] = [
  {
    title: t('物料编码'),
    dataIndex: 'ITEM_CODE',
    resizable: true,
    sorter: true,
    width: 200,
  },
  {
    title: t('物料名称'),
    dataIndex: 'ITEM_NAME',
    resizable: true,
    sorter: true,
    width: 300,
  },
  {
    title: t('操作时间'),
    dataIndex: 'UPDATE_TIME',
    resizable: true,
    sorter: true,
    width: 300,
  },
  {
    title: t('结果'),
    dataIndex: 'RESULT',
    resizable: true,
    sorter: true,
    width: 180,
    customRender: ({ record }) => {
      const status = record.RESULT;
      var text = '';
      var color = '';
      switch (status) {
        case 0:
          text = '无结果';
          color = 'green';
          break;
        case 1:
          text = '平帐';
          color = 'blue';
          break;
        case 2:
          text = '盘盈';
          color = '#C2C247';
          break;
        case 3:
          text = '盘亏';
          color = '#C2C247';
          break;
        default:
          break;
      }
      return h(Tooltip, { title: t('xxxxxx') }, () => h(Tag, { color: color }, () => text));
    },
  },
  {
    title: t('ERP仓库'),
    dataIndex: 'ERP_WH',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: t('库存数量'),
    dataIndex: 'QTY',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: t('盘点数量'),
    dataIndex: 'ACT_QTY',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: t('差异数量'),
    dataIndex: 'NOT_QTY',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: t('ERP数量'),
    dataIndex: 'ERP_QTY',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: t('条码库存数量'),
    dataIndex: 'SN_QTY',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: t('条码盘点数量'),
    dataIndex: 'ACT_SN_QTY',
    resizable: true,
    sorter: true,
    width: 180,
  },
  {
    title: t('ERP与库存差异数量'),
    dataIndex: 'ERP_NOT_QTY',
    resizable: true,
    sorter: true,
    width: 180,
  },

]
